==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaOOdplatnosci.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.TypDecyzjiOOdplatnosci;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DecyzjaOOdplatnosci extends GenericDPSObject {
    /**
     * DECYZJA_O_ODPLATNOSCI.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DECYZJA_O_ODPLATNOSCI.CZLONEK_RODZ_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long czlonekRodzId;

    /**
     * DECYZJA_O_ODPLATNOSCI.DOCHOD_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dochodId;

    /**
     * DECYZJA_O_ODPLATNOSCI.KTO_WYDAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ktoWydalId;

    /**
     * DECYZJA_O_ODPLATNOSCI.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long mieszkaniecId;

    /**
     * DECYZJA_O_ODPLATNOSCI.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * DECYZJA_O_ODPLATNOSCI.CALKOWITE_ZWOLNIENIE
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean calkowiteZwolnienie;

    /**
     * DECYZJA_O_ODPLATNOSCI.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWydania;

    /**
     * DECYZJA_O_ODPLATNOSCI.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * DECYZJA_O_ODPLATNOSCI.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * DECYZJA_O_ODPLATNOSCI.KWOTA_ZWOLNIONA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaZwolniona;

    /**
     * DECYZJA_O_ODPLATNOSCI.OBOWIAZUJE_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date obowiazujeOd;

    /**
     * DECYZJA_O_ODPLATNOSCI.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypDecyzjiOOdplatnosci typ;

    /**
     * DECYZJA_O_ODPLATNOSCI.WAZNA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date waznaDo;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_O_ODPLATNOSCI.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.CZLONEK_RODZ_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getCzlonekRodzId() {
        return czlonekRodzId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.CZLONEK_RODZ_ID
     *
     * @param czlonekRodzId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCzlonekRodzId(Long czlonekRodzId) {
        this.czlonekRodzId = czlonekRodzId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.DOCHOD_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDochodId() {
        return dochodId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.DOCHOD_ID
     *
     * @param dochodId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDochodId(Long dochodId) {
        this.dochodId = dochodId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.KTO_WYDAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKtoWydalId() {
        return ktoWydalId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.KTO_WYDAL_ID
     *
     * @param ktoWydalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKtoWydalId(Long ktoWydalId) {
        this.ktoWydalId = ktoWydalId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.MIESZKANIEC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.CALKOWITE_ZWOLNIENIE
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getCalkowiteZwolnienie() {
        return calkowiteZwolnienie;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.CALKOWITE_ZWOLNIENIE
     *
     * @param calkowiteZwolnienie
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCalkowiteZwolnienie(Boolean calkowiteZwolnienie) {
        this.calkowiteZwolnienie = calkowiteZwolnienie;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.DATA_WYDANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.KWOTA_ZWOLNIONA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaZwolniona() {
        return kwotaZwolniona;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.KWOTA_ZWOLNIONA
     *
     * @param kwotaZwolniona
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaZwolniona(BigDecimal kwotaZwolniona) {
        this.kwotaZwolniona = kwotaZwolniona;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.OBOWIAZUJE_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getObowiazujeOd() {
        return obowiazujeOd;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.OBOWIAZUJE_OD
     *
     * @param obowiazujeOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setObowiazujeOd(Date obowiazujeOd) {
        this.obowiazujeOd = obowiazujeOd;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypDecyzjiOOdplatnosci getTyp() {
        return typ;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypDecyzjiOOdplatnosci typ) {
        this.typ = typ;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.WAZNA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getWaznaDo() {
        return waznaDo;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.WAZNA_DO
     *
     * @param waznaDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWaznaDo(Date waznaDo) {
        this.waznaDo = waznaDo;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaOOdplatnosci other = (DecyzjaOOdplatnosci) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getCzlonekRodzId() == null ? other.getCzlonekRodzId() == null : this.getCzlonekRodzId().equals(other.getCzlonekRodzId()))
            && (this.getDochodId() == null ? other.getDochodId() == null : this.getDochodId().equals(other.getDochodId()))
            && (this.getKtoWydalId() == null ? other.getKtoWydalId() == null : this.getKtoWydalId().equals(other.getKtoWydalId()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getCalkowiteZwolnienie() == null ? other.getCalkowiteZwolnienie() == null : this.getCalkowiteZwolnienie().equals(other.getCalkowiteZwolnienie()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getKwotaZwolniona() == null ? other.getKwotaZwolniona() == null : this.getKwotaZwolniona().equals(other.getKwotaZwolniona()))
            && (this.getObowiazujeOd() == null ? other.getObowiazujeOd() == null : this.getObowiazujeOd().equals(other.getObowiazujeOd()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getWaznaDo() == null ? other.getWaznaDo() == null : this.getWaznaDo().equals(other.getWaznaDo()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getCzlonekRodzId() == null) ? 0 : getCzlonekRodzId().hashCode());
        result = prime * result + ((getDochodId() == null) ? 0 : getDochodId().hashCode());
        result = prime * result + ((getKtoWydalId() == null) ? 0 : getKtoWydalId().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getCalkowiteZwolnienie() == null) ? 0 : getCalkowiteZwolnienie().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getKwotaZwolniona() == null) ? 0 : getKwotaZwolniona().hashCode());
        result = prime * result + ((getObowiazujeOd() == null) ? 0 : getObowiazujeOd().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getWaznaDo() == null) ? 0 : getWaznaDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", czlonekRodzId=").append(czlonekRodzId);
        sb.append(", dochodId=").append(dochodId);
        sb.append(", ktoWydalId=").append(ktoWydalId);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", calkowiteZwolnienie=").append(calkowiteZwolnienie);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", nr=").append(nr);
        sb.append(", kwota=").append(kwota);
        sb.append(", kwotaZwolniona=").append(kwotaZwolniona);
        sb.append(", obowiazujeOd=").append(obowiazujeOd);
        sb.append(", typ=").append(typ);
        sb.append(", waznaDo=").append(waznaDo);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaOOdplatnosci.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.TypDecyzjiOOdplatnosci;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DecyzjaOOdplatnosci extends GenericDPSObject {
    /**
     * DECYZJA_O_ODPLATNOSCI.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DECYZJA_O_ODPLATNOSCI.CZLONEK_RODZ_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long czlonekRodzId;

    /**
     * DECYZJA_O_ODPLATNOSCI.DOCHOD_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dochodId;

    /**
     * DECYZJA_O_ODPLATNOSCI.KTO_WYDAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ktoWydalId;

    /**
     * DECYZJA_O_ODPLATNOSCI.MIESZKANIEC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long mieszkaniecId;

    /**
     * DECYZJA_O_ODPLATNOSCI.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * DECYZJA_O_ODPLATNOSCI.CALKOWITE_ZWOLNIENIE
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean calkowiteZwolnienie;

    /**
     * DECYZJA_O_ODPLATNOSCI.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWydania;

    /**
     * DECYZJA_O_ODPLATNOSCI.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * DECYZJA_O_ODPLATNOSCI.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * DECYZJA_O_ODPLATNOSCI.KWOTA_ZWOLNIONA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaZwolniona;

    /**
     * DECYZJA_O_ODPLATNOSCI.OBOWIAZUJE_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date obowiazujeOd;

    /**
     * DECYZJA_O_ODPLATNOSCI.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypDecyzjiOOdplatnosci typ;

    /**
     * DECYZJA_O_ODPLATNOSCI.WAZNA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date waznaDo;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_O_ODPLATNOSCI.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.CZLONEK_RODZ_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getCzlonekRodzId() {
        return czlonekRodzId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.CZLONEK_RODZ_ID
     *
     * @param czlonekRodzId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCzlonekRodzId(Long czlonekRodzId) {
        this.czlonekRodzId = czlonekRodzId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.DOCHOD_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDochodId() {
        return dochodId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.DOCHOD_ID
     *
     * @param dochodId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDochodId(Long dochodId) {
        this.dochodId = dochodId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.KTO_WYDAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKtoWydalId() {
        return ktoWydalId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.KTO_WYDAL_ID
     *
     * @param ktoWydalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKtoWydalId(Long ktoWydalId) {
        this.ktoWydalId = ktoWydalId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.MIESZKANIEC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getMieszkaniecId() {
        return mieszkaniecId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.MIESZKANIEC_ID
     *
     * @param mieszkaniecId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMieszkaniecId(Long mieszkaniecId) {
        this.mieszkaniecId = mieszkaniecId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.CALKOWITE_ZWOLNIENIE
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getCalkowiteZwolnienie() {
        return calkowiteZwolnienie;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.CALKOWITE_ZWOLNIENIE
     *
     * @param calkowiteZwolnienie
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCalkowiteZwolnienie(Boolean calkowiteZwolnienie) {
        this.calkowiteZwolnienie = calkowiteZwolnienie;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.DATA_WYDANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.KWOTA_ZWOLNIONA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaZwolniona() {
        return kwotaZwolniona;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.KWOTA_ZWOLNIONA
     *
     * @param kwotaZwolniona
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaZwolniona(BigDecimal kwotaZwolniona) {
        this.kwotaZwolniona = kwotaZwolniona;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.OBOWIAZUJE_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getObowiazujeOd() {
        return obowiazujeOd;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.OBOWIAZUJE_OD
     *
     * @param obowiazujeOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setObowiazujeOd(Date obowiazujeOd) {
        this.obowiazujeOd = obowiazujeOd;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypDecyzjiOOdplatnosci getTyp() {
        return typ;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypDecyzjiOOdplatnosci typ) {
        this.typ = typ;
    }

    /**
     * @return DECYZJA_O_ODPLATNOSCI.WAZNA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getWaznaDo() {
        return waznaDo;
    }

    /**
     * DECYZJA_O_ODPLATNOSCI.WAZNA_DO
     *
     * @param waznaDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWaznaDo(Date waznaDo) {
        this.waznaDo = waznaDo;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaOOdplatnosci other = (DecyzjaOOdplatnosci) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getCzlonekRodzId() == null ? other.getCzlonekRodzId() == null : this.getCzlonekRodzId().equals(other.getCzlonekRodzId()))
            && (this.getDochodId() == null ? other.getDochodId() == null : this.getDochodId().equals(other.getDochodId()))
            && (this.getKtoWydalId() == null ? other.getKtoWydalId() == null : this.getKtoWydalId().equals(other.getKtoWydalId()))
            && (this.getMieszkaniecId() == null ? other.getMieszkaniecId() == null : this.getMieszkaniecId().equals(other.getMieszkaniecId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getCalkowiteZwolnienie() == null ? other.getCalkowiteZwolnienie() == null : this.getCalkowiteZwolnienie().equals(other.getCalkowiteZwolnienie()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getKwotaZwolniona() == null ? other.getKwotaZwolniona() == null : this.getKwotaZwolniona().equals(other.getKwotaZwolniona()))
            && (this.getObowiazujeOd() == null ? other.getObowiazujeOd() == null : this.getObowiazujeOd().equals(other.getObowiazujeOd()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getWaznaDo() == null ? other.getWaznaDo() == null : this.getWaznaDo().equals(other.getWaznaDo()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getCzlonekRodzId() == null) ? 0 : getCzlonekRodzId().hashCode());
        result = prime * result + ((getDochodId() == null) ? 0 : getDochodId().hashCode());
        result = prime * result + ((getKtoWydalId() == null) ? 0 : getKtoWydalId().hashCode());
        result = prime * result + ((getMieszkaniecId() == null) ? 0 : getMieszkaniecId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getCalkowiteZwolnienie() == null) ? 0 : getCalkowiteZwolnienie().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getKwotaZwolniona() == null) ? 0 : getKwotaZwolniona().hashCode());
        result = prime * result + ((getObowiazujeOd() == null) ? 0 : getObowiazujeOd().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getWaznaDo() == null) ? 0 : getWaznaDo().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", czlonekRodzId=").append(czlonekRodzId);
        sb.append(", dochodId=").append(dochodId);
        sb.append(", ktoWydalId=").append(ktoWydalId);
        sb.append(", mieszkaniecId=").append(mieszkaniecId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", calkowiteZwolnienie=").append(calkowiteZwolnienie);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append(", nr=").append(nr);
        sb.append(", kwota=").append(kwota);
        sb.append(", kwotaZwolniona=").append(kwotaZwolniona);
        sb.append(", obowiazujeOd=").append(obowiazujeOd);
        sb.append(", typ=").append(typ);
        sb.append(", waznaDo=").append(waznaDo);
        sb.append("]");
        return sb.toString();
    }
}
